local RepCalc = CreateFrame("Frame")
RepCalc:RegisterEvent("ADDON_LOADED")
RepCalc:RegisterEvent("PLAYER_LOGOUT")
RepCalc:RegisterEvent("UPDATE_FACTION")
local L = LibStub("AceLocale-3.0"):GetLocale("RepCalc")
local RC_LDB = LibStub:GetLibrary("LibDataBroker-1.1"):NewDataObject("RepCalc", {
	type = "data source",
	icon = "Interface/ICONS/Achievement_Reputation_06",
	label = "RepCalc",
	OnClick = function(clickedframe, button)
		if button == "LeftButton" then
			RepCalc.BrokerMenu()
		elseif button == "RightButton" then
			if _G["RepCalc_Config"] == nil then RepCalc.CreateConfig() end
			if _G["RepCalc_Header"] == nil then RepCalc.CreateBars() end
			if RepCalcDB.RunSetup == nil then 
				RepCalcDB.RunSetup = true; RepCalc.FillConfig(); RepCalc.ConfigShow()
			else 
				RepCalc.Hide()
				RepCalc.ConfigShow()
			end
		end
	end,
	OnTooltipShow = function(tt)
		tt:ClearLines()
		tt:AddLine("RepCalc")
		tt:AddLine("Left-Click to track a faction.")
		tt:AddLine("Right-Click to open the configuration.")
		if RepCalcDB.RepName then
			tt:AddLine(" ")
			for i = 1, 45 do
				if RepCalcDB.RepNum[i] == 1 then
					local topVal, earntVal, totalReq, standName = RepCalc.CalcRep(RepCalcDB.RepName[i])
					local RepPercent = ceil((earntVal/topVal)*100)
					tt:AddDoubleLine("|cffffffff"..RepCalcDB.RepName[i]..": |cff00FF7F"..standName, earntVal.."/"..topVal.." ("..RepPercent.."%)")
				end
			end
		end
	end,
})

function RepCalc:OnEvent(event, arg1)
	if event == "ADDON_LOADED" and arg1 == "RepCalc" then
		RepCalcDB = RepCalcDB or {}
		if RepCalcDB.RepName then RepCalc.CreateBars(); RepCalc.CreateConfig(); RepCalcDB.RunSetup = true; RepCalcDB.ConfigOpen = false; RepCalc:UnregisterEvent("ADDON_LOADED"); end
	elseif event == "PLAYER_LOGOUT" then
		if RepCalcDB.RepName[1] == nil then RepCalcDB = nil; RepCalc:UnregisterEvent("PLAYER_LOGOUT"); end
	elseif event == "UPDATE_FACTION" then
		if RepCalcDB.RunSetup == true and RepCalcDB.Visible == true then RepCalc.Update(); end
		if RepCalcDB.Tracked then 
			local topVal, earntVal, totalReq, standName = RepCalc.CalcRep(RepCalcDB.Tracked)
			if topVal ~= nil then 
				local RepPercent = ceil((earntVal/topVal)*100)
				RC_LDB.text = RepCalcDB.Tracked..": |cff00FF7F"..earntVal.."/"..topVal.." ("..RepPercent.."%)" 
			end
		end

	end
end
RepCalc:SetScript("OnEvent", RepCalc.OnEvent)

SLASH_REPCALC1 = '/repcalc';
function SlashCmdList.REPCALC(msg, editbox)
	if _G["RepCalc_Config"] == nil then RepCalc.CreateConfig() end
	if _G["RepCalc_Header"] == nil then RepCalc.CreateBars() end
	if RepCalcDB.RunSetup == nil then 
		RepCalc.ConfigShow(); RepCalcDB.RunSetup = true 
	elseif RepCalcDB.ConfigOpen == false then 
		RepCalc.Update()
	end
end

SLASH_RCCONFIG1 = '/rcconfig';
function SlashCmdList.RCCONFIG(msg, editbox)
	if _G["RepCalc_Config"] == nil then RepCalc.CreateConfig() end
	if _G["RepCalc_Header"] == nil then RepCalc.CreateBars() end
	if RepCalcDB.RunSetup == nil then 
		RepCalcDB.RunSetup = true; RepCalc.FillConfig(); RepCalc.ConfigShow()
	else 
		RepCalc.Hide()
		RepCalc.ConfigShow()
	end
end

function RepCalc.BrokerMenu()
	local faction, menu = {}, {}
	local RepFound
	if RepCalcDB.RepNum then for i = 1, 45 do if RepCalcDB.RepNum[i] == 1 then RepFound = 1; break end end end
	if RepFound then
		faction.text = "RepCalc: Choose Faction to Track"
		faction.isTitle = true; faction.notCheckable = true
		tinsert(menu, faction)

		for i = 1, 45 do
			if RepCalcDB.RepNum[i] == 1 then
				faction = {}
				local topVal, earntVal, totalReq, standName = RepCalc.CalcRep(RepCalcDB.RepName[i])
				local RepPercent = ceil((earntVal/topVal)*100)

				faction.checked = false; faction.hasArrow = false
				if RepCalcDB.RepName[i] == RepCalcDB.Tracked then faction.checked = true end
				faction.text = RepCalcDB.RepName[i]..": ".."|cff00FF7F ("..earntVal.."/"..topVal..") "..standName
				faction.func = function () 
					RC_LDB.text = RepCalcDB.RepName[i].. ": |cff00FF7F"..earntVal.."/"..topVal.." ("..RepPercent.."%)"
					RepCalcDB.Tracked = RepCalcDB.RepName[i] 
				end
				tinsert(menu, faction)
			end
		end

		faction = {}
		faction.checked = false; faction.hasArrow = false; faction.text = "** Disable Tracking"
		faction.func = function() RC_LDB.text = "RepCalc"; RepCalcDB.Tracked = nil end
		tinsert(menu, faction)

	else
		faction.text = "RepCalc: No factions currently being tracked."
		faction.isTitle = true; faction.notCheckable = true
		tinsert(menu, faction)
	end
	local menuFrame = CreateFrame("Frame", "RepCalc_Menu", UIParent, "UIDropDownMenuTemplate")
	menuFrame:Hide()
	EasyMenu(menu, menuFrame, "cursor", 0 , 0, "MENU");
end


function RepCalc.CreateConfig()
	local fra = CreateFrame("Frame","RepCalc_Config",UIParent)
	fra:SetSize(615, 450)
	fra:SetFrameStrata("HIGH")
	fra:SetMovable(true)
	fra:EnableMouse(true)
	fra:RegisterForDrag("LeftButton")
	fra:SetScript("OnDragStart", fra.StartMoving)
	fra:SetScript("OnDragStop", fra.StopMovingOrSizing)
	fra:SetPoint("CENTER") 
	fra:Hide()
	local tex = fra:CreateTexture("$parent_Background","ARTWORK")
	tex:SetTexture(0, 0, 0); tex:SetAlpha(0.8)
	tex:SetAllPoints(fra)
	local ttl = fra:CreateFontString("HeaderText","OVERLAY","GameFontNormal") --Header
	ttl:SetPoint("TOPLEFT",fra,"TOPLEFT",4,-3)
	ttl:SetText("RepCalc Configuration")
	local desc = fra:CreateFontString("HeaderDesc","OVERLAY","GameFontNormalSmall") --Help Text
	desc:SetPoint("TOPLEFT",fra,"TOPLEFT",5,-22)
	desc:SetText("Select reputations to track (10 maximum).\nKey: |cff00FF7FMists of Pandaria, |cFFFF6060Cataclysm, |cFF1E90FFWrath of the Lich King, |cFF9370DBBurning Crusade.")
	desc:SetJustifyH("LEFT")
	local ttle = fra:CreateFontString("TitleError","OVERLAY","GameFontNormalSmall") --Error Text
	ttle:SetPoint("TOPLEFT",fra,"TOPLEFT",6,-62)
	ttle:SetText("No honored or revered reputations found.")
	ttle:Hide()
	local btn = CreateFrame("Button","RepCalc.ConfigButton",fra,"UIPanelButtonTemplate") --Save Button
	btn:SetSize(70, 25)
	btn:SetPoint("TOPRIGHT",fra,"TOPRIGHT",-2,-2)
	btn:SetText("Save")
	btn:SetScript("OnClick", function (self, button, down) if button == "LeftButton" then RepCalc.ConfigButton(); end end)
	btn:Show()
	--Checkboxes
	local x = 2
	local y = -55
	for i = 1, 45 do
		local chkbox = CreateFrame("CheckButton", "$parent_CheckButton"..i, fra, "UICheckButtonTemplate")
		local checktxt =  _G[chkbox:GetName().."Text"]
		chkbox:SetSize(25, 25)
		checktxt:SetJustifyH("Left")
		if i == 16 then x = 205; y = -55 end --2nd column
		if i == 31 then x = 410; y = -55 end --3rd column
		chkbox:SetPoint("TOPLEFT",fra,"TOPLEFT",x, y)
		y = y - 25		
	end
end

function RepCalc.CreateBars()
	-- Header
	local fra = CreateFrame("Frame","RepCalc_Header",UIParent)
	fra:SetSize(215, 23)
	fra:SetFrameStrata("HIGH")
	fra:SetMovable(true)
	fra:EnableMouse(true)
	fra:RegisterForDrag("LeftButton")
	fra:SetScript("OnDragStart", fra.StartMoving)
	fra:SetScript("OnDragStop", fra.StopMovingOrSizing)
	fra:SetScript("OnMouseUp", function (self, button) if button == "RightButton" then RepCalc.Hide(); RepCalc.ConfigShow() end end)
	fra:SetPoint("CENTER"); 
	fra:Hide()
	local tex = fra:CreateTexture("$parent_Background","ARTWORK")
	tex:SetAllPoints()
	tex:SetTexture(0, 0, 0, 0.7)
	-- Title
	local ttl = fra:CreateFontString("HeaderText","OVERLAY","GameFontNormal")
	ttl:SetPoint("TOPLEFT",fra,"TOPLEFT",4,-5)
	ttl:SetText("RepCalc")
	-- Close Button
	local btn = CreateFrame("Button","$parent_CloseButton",fra,"UIPanelCloseButton")
	btn:SetPoint("TOPRIGHT",fra,"TOPRIGHT",5,5)
	btn:SetScript("OnClick", function (self, button, down) if button == "LeftButton" then RepCalc.Hide() end end)
	btn:Show()
	--Rep Bars
	local fraTop = fra
	local fraBelow
	for i = 1, 10 do
		--Rep Bar Frame
		fraBelow = CreateFrame("Frame","RepCalc_Frame"..i,fra)
		fraBelow:SetPoint("TOPLEFT",fraTop,"BOTTOMLEFT",0,0)
		fraBelow:SetSize(215, 25)
		fraBelow:SetScript("OnMouseUp", function (self, button) if button == "LeftButton" then RepCalc.ShowRep(i) end end)
		fraBelow:Hide()
		local tex = fraBelow:CreateTexture("$parent_Background","BACKGROUND")
		tex:SetAllPoints();
		tex:SetTexture(0, 0, 0, 0.6)
		--StatusBar
		bar = CreateFrame("StatusBar", "RepCalc_StatusBar"..i, fraBelow)
		bar:SetSize(212, 25)
		bar:SetAllPoints("RepCalc_Frame"..i)
		bar:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar")
		bar:SetMinMaxValues(0, 1000)
		bar:SetStatusBarColor(0, 0.6, 0, 1)
		bar:Show()
		--StatusBar Text
		bartxt = bar:CreateFontString("RepCalc_StatusBar"..i.."Text",nil,"GameFontNormalSmall")
		bartxt:SetPoint("TOPLEFT",bar,"TOPLEFT",3,1)
		bartxt:SetSize(212, 25)
		bartxt:SetJustifyH("LEFT"); bartxt:SetJustifyV("MIDDLE")
		bartxt:SetAlpha(1)
		bartxt:Show()
		fraTop = fraBelow
	end
end

function RepCalc.Hide()
	RepCalcDB.Visible = false
	local frheader = _G["RepCalc_Header"]
	frheader:Hide()
	for i = 1, 10 do
		local fr = _G["RepCalc_Frame"..i]
		fr:Hide()
	end
end

function RepCalc.ConfigShow()
	local rc_config = _G["RepCalc_Config"]
	RepCalc.FillConfig()
	rc_config:Show()
	RepCalcDB.ConfigOpen = true
end

function RepCalc.ConfigHide()
	local rc_config = _G["RepCalc_Config"]
	rc_config:Hide()
	RepCalcDB.ConfigOpen = false
end

function RepCalc.MakeBar(num, value)
	local topVal, earntVal, totalReq, standName = RepCalc.CalcRep(RepCalcDB.RepName[value])
	local RepPercent = (earntVal / topVal)*1000; 
	local RepText = RepCalcDB.RepName[value] .. " (" .. earntVal .. "/" .. topVal .. ")\n"..standName
	local bar = _G["RepCalc_StatusBar" .. num]
	local bartxt = _G["RepCalc_StatusBar" .. num .. "Text"]
	bar:SetValue(RepPercent)
	bartxt:SetText(RepText)
	if topVal == 3000 then bar:SetStatusBarColor(0.7, 0.4, 0, 1) elseif topVal == 6000 then bar:SetStatusBarColor(0, 0.7, 0, 1)--Neutral/Friendly
	elseif topVal == 12000 then bar:SetStatusBarColor(0, 0.6, 0, 1) else bar:SetStatusBarColor(0, 0.5, 0, 1) end--Honored/Revered

	local currentID 
	for i = 1, 200 do
		local name, description, standingId, barMin, barMax, barValue, atWarWith, canToggleAtWar, isHeader, isCollapsed, hasRep, isWatched, isChild, factionID = GetFactionInfo(i);
		if name == RepCalcDB.RepName[value] then currentID = factionID; break end
	end
	local friendID, friendRep, friendMaxRep, friendName, friendText, friendTexture, friendReaction, friendThresh, friendNextThresh = GetFriendshipReputation(currentID);
	if friendID ~= nil then
		if friendRep < 8400 then bar:SetStatusBarColor(0.7, 0.4, 0, 1)
		elseif friendRep >= 8400 and friendRep < 16800 then bar:SetStatusBarColor(0, 0.7, 0, 1)
		elseif friendRep >= 16800 and friendRep < 25200 then bar:SetStatusBarColor(0, 0.6, 0, 1)
		elseif friendRep >= 25200 and friendRep < 33600 then bar:SetStatusBarColor(0, 0.6, 0, 1)
		else bar:SetStatusBarColor(0, 0.5, 0, 1) end
	end

end

function RepCalc.FillConfig()

	local tempName, repPercent, highVal, prevVal = nil,nil,0,0
	local trackedReps = {}
	local MoPReps = { L["Golden Lotus"],L["Order of the Cloud Serpent"],L["Shado-Pan"],L["The August Celestials"],L["The Black Prince"],L["The Klaxxi"],L["The Lorewalkers"],L["The Anglers"],L["Nat Pagle"],L["The Tillers"],
		L["Chee Chee"],L["Ella"],L["Farmer Fung"],L["Fish Fellreed"],L["Gina Mudclaw"],L["Haohan Mudclaw"],L["Jogu the Drunk"],L["Old Hillpaw"],"Sho",L["Tina Mudclaw"],L["Operation: Shieldwall"],L["Dominance Offensive"],
		L["Sunreaver Onslaught"],L["Kirin Tor Offensive"],L["Shado-Pan Assault"]}
	local CataReps = { L["Avengers of Hyjal"],L["Baradin's Wardens"],L["Hellscream's Reach"],L["Guardians of Hyjal"],L["Ramkahen"],L["The Earthen Ring"],L["Therazane"],L["Wildhammer Clan"],L["Dragonmaw Clan"]}
	local WrathReps = { L["Argent Crusade"],L["Kirin Tor"],L["Knights of the Ebon Blade"],L["The Ashen Verdict"],L["The Kalu'ak"],L["The Sons of Hodir"],L["The Wyrmrest Accord"],L["Alliance Vanguard"],
		L["Explorers' League"],L["The Frostborn"],L["The Silver Covenant"],L["Valiance Expedition"]}
	local BCReps = { L["Cenarion Expedition"],L["Honor Hold"],L["Keepers of Time"],L["Kurenai"],L["Netherwing"],L["Ogri'la"],L["Sporeggar"],L["The Consortium"],L["The Violet Eye"],L["Lower City"],L["Sha'tari Skyguard"],
		L["Shattered Sun Offensive"],L["The Aldor"],L["The Scryers"],L["The Sha'tar"]}

	if RepCalcDB.RepName ~= nil then 
		for i = 1, #RepCalcDB.RepName do
			if RepCalcDB.RepNum[i] == 1 then tinsert(trackedReps, RepCalcDB.RepName[i]); end
		end
	end

	if not RepCalcDB.RepNum then RepCalcDB.RepNum = {} end
	RepCalcDB.RepName = {}
	local currentID, standID = 0,0

	for i = 1, 45 do -- Uncheck all boxes
		local checkbox = _G["RepCalc_Config_CheckButton" .. i]
		checkbox:SetChecked(false)
	end

	for i = 1, 45 do
		for idx = 1, 200 do -- Find next highest faction
			local name, description, standingId, barMin, barMax, barValue, atWarWith, canToggleAtWar, isHeader, isCollapsed, hasRep, isWatched, isChild, factionID = GetFactionInfo(idx);
			if not name or name == "Inactive" then break end
			if standingId > 3 and standingId < 8 and name ~= L["Guild"] and name ~= L["Alliance"] and name ~= L["Alliance Forces"] and name ~= L["Horde"] and name ~= L["Horde Forces"] and name ~= L["Steamwheedle Cartel"] and name ~= L["Sholazar Basin"] and name ~= L["Bizmo's Brawlpub"] and name ~= L["Brawl'gar Arena"] then
				if barValue > highVal and (barValue < prevVal or prevVal == 0) then
						highVal = barValue
						currentID = factionID
						tempName = name
						repPercent = ceil((barValue - barMin) / (barMax - barMin) * 100)
						standID = standingId
				end
			end
		end
		
		if RepCalcDB.RepName[i-1] == tempName and i > 1 then break -- Run out of reps
		elseif repPercent ~= nil then 
			prevVal = highVal; highVal = 0
			if RepCalcDB.RepNum[1] == nil then RepCalcDB.RepNum[i] = 0; end 
			RepCalcDB.RepName[i] = tempName

			local checkbox = _G["RepCalc_Config_CheckButton" .. i]
			local checktxt =  _G[checkbox:GetName().."Text"]
			local friendID, friendRep, friendMaxRep, friendName, friendText, friendTexture, friendReaction, friendThresh, friendNextThresh = GetFriendshipReputation(currentID)
			if (friendRep ~= nil) then
				if friendRep < 8400 then checktxt:SetText(tempName.." (" .. repPercent .. "%)\n"..L["Stranger"])
				elseif friendRep >= 8400 and friendRep < 16800 then checktxt:SetText(tempName.." (" .. repPercent .. "%)\n"..L["Acquaintance"])
				elseif friendRep >= 16800 and friendRep < 25200 then checktxt:SetText(tempName.." (" .. repPercent .. "%)\n"..L["Buddy"])
				elseif friendRep >= 25200 and friendRep < 33600 then checktxt:SetText(tempName.." (" .. repPercent .. "%)\n"..L["Friend"])
				elseif friendRep >= 33600 and friendRep < 42000 then checktxt:SetText(tempName.." (" .. repPercent .. "%)\n"..L["Good Friend"])
				end
			else
				if standID == 4 then checktxt:SetText(tempName .. " (" .. repPercent .. "%)\n"..L["Neutral"])
				elseif standID == 5 then checktxt:SetText(tempName .. " (" .. repPercent .. "%)\n"..L["Friendly"])
				elseif standID == 6 then checktxt:SetText(tempName .. " (" .. repPercent .. "%)\n"..L["Honored"])
				else checktxt:SetText(tempName .. " (" .. repPercent .. "%)\n"..L["Revered"]); end
			end
			--Colour the factions
			for i = 1, #MoPReps do if tempName == MoPReps[i] then _G[checkbox:GetName().."Text"]:SetText("|cff00FF7F".._G[checkbox:GetName().."Text"]:GetText()) end end
			for i = 1, #CataReps do if tempName == CataReps[i] then _G[checkbox:GetName().."Text"]:SetText("|cFFFF6060".._G[checkbox:GetName().."Text"]:GetText()) end end
			for i = 1, #WrathReps do if tempName == WrathReps[i] then _G[checkbox:GetName().."Text"]:SetText("|cFF1E90FF".._G[checkbox:GetName().."Text"]:GetText()) end end
			for i = 1, #BCReps do if tempName == BCReps[i] then _G[checkbox:GetName().."Text"]:SetText("|cFF9370DB".._G[checkbox:GetName().."Text"]:GetText()) end end
			checkbox:Show()
			if #trackedReps ~= 0 then
				for i = 1, #trackedReps do --Compare to previously tracked reps
					if trackedReps[i] == tempName then checkbox:SetChecked(true); end
				end
			end
		end
	end
	for i = 1, 45 do -- Hide unused checkboxes
		if RepCalcDB.RepName[i] == nil then
			local checkbox = _G["RepCalc_Config_CheckButton" .. i]
			checkbox:Hide()
		end
	end
	local errString = _G["TitleError"] -- Hide/Show error text if no reps
	if tempName == "" then errString:Show()
	else errString:Hide() end
	local fra = _G["RepCalc_Config"] -- Resize frame if low amount of reps
	if #RepCalcDB.RepName < 31 then fra:SetSize(500, 450) else fra:SetSize(615, 450) end
end

function RepCalc.ConfigButton()
	if RepCalcDB.RepName[1] ~= nil then
		local maxNum,repFound = 1, 0
		for i = 1, 45 do
			if maxNum > 10 then maxNum=i; break end --Maximum 10 reps
			local checkbox = _G["RepCalc_Config_CheckButton" .. i]
			if checkbox:GetChecked() then RepCalcDB.RepNum[i] = 1; maxNum=maxNum+1 else RepCalcDB.RepNum[i] = nil end
			if RepCalcDB.RepName[i] == RepCalcDB.Tracked then 
				if RepCalcDB.RepNum[i] ~= 1 then repFound = 0 else repFound = 1 end
			end
		end
		if repFound == 0 then RC_LDB.text = "RepCalc"; RepCalcDB.Tracked = nil end
		for i = maxNum, 45 do --Uncheck boxes past 10 max
			local checkbox = _G["RepCalc_Config_CheckButton" .. i]
			checkbox:SetChecked(0)
		end
		RepCalc.ConfigHide()
		RepCalc.Update()
	else
		RepCalc.ConfigHide()
		RepCalcDB.RunSetup = nil
	end
end

function RepCalc.Update()
	RepCalcDB.Visible = true
	local headerframe = _G["RepCalc_Header"]
	headerframe:Show()
	local barnum = 1
	for repnum = 1, 45 do
		if RepCalcDB.RepNum[repnum] == 1 then
			local topVal, earntVal, totalReq = RepCalc.CalcRep(RepCalcDB.RepName[repnum])
			local fr = _G["RepCalc_Frame" .. barnum]
			if barnum <= 10 then
				if topVal ~= nil then -- zoning error bugfix
					RepCalc.MakeBar(barnum, repnum)
					fr:Show()
					barnum=barnum+1
				end
			end
		end
	end
end

function RepCalc.CalcRep(faction)
	local topVal
	local earntVal
	local totalReq
	local standName
	local hasBonus
	for factionIndex = 1, 200 do
		  local name, description, standingId, barMin, barMax, barValue, atWarWith, canToggleAtWar, isHeader, isCollapsed, hasRep, isWatched, isChild, factionID, hasBonusRepGain, canBeLFGBonus = GetFactionInfo(factionIndex)
		  if not name then break
		  elseif name == faction then
		    if standingId == 7 then totalReq = (barMax - barValue); standName = L["Revered"]
		    elseif standingId == 6 then totalReq = (barMax - barValue)+21000; standName = L["Honored"]
		    elseif standingId == 5 then totalReq = (barMax - barValue)+33000; standName = L["Friendly"]
		    elseif standingId == 4 then totalReq = (barMax - barValue)+39000; standName = L["Neutral"] else standName = L["Exalted"] end
		    topVal = barMax - barMin; earntVal = barValue - barMin
		    hasBonus = hasBonusRepGain
		    local friendID, friendRep, friendMaxRep, friendName, friendText, friendTexture, friendReaction, friendThresh, friendNextThresh = GetFriendshipReputation(factionID);
		    if friendRep ~= nil then
			topVal = 8400
			earntVal = friendRep - friendThresh
			if friendRep < 8400 then standName = L["Stranger"]
			elseif friendRep >= 8400 and friendRep < 16800 then standName = L["Acquaintance"]
			elseif friendRep >= 16800 and friendRep < 25200 then standName = L["Buddy"]
			elseif friendRep >= 25200 and friendRep < 33600 then standName = L["Friend"]
			elseif friendRep >= 33600 and friendRep < 42000 then standName = L["Good Friend"] 
			else topVal = 999; standName = L["Best Friend"] end
		    end
		    break
		  end
	end
	return topVal, earntVal, totalReq, standName, hasBonus
end

function RepCalc.ShowRep(barnum)
  local x, RC_Bonus = 1, 1
  for i = 1, 45 do
    if RepCalcDB.RepNum[i] == 1 then
      if x < barnum then x=x+1
      else
        --Calc any rep bonuses
        if UnitRace("player") == "Human" then RC_Bonus = 1.1 end
        if IsInGuild() == 1 then
          if GetGuildLevel() > 11 then RC_Bonus = RC_Bonus + 0.1 elseif GetGuildLevel() > 3 then RC_Bonus = RC_Bonus + 0.05 end
        end
	--Calc requirements to exalted
        local RepName = RepCalcDB.RepName[i]
	local RepTop, RepAmt, RepTotal, standName, hasBonus = RepCalc.CalcRep(RepName)
	if RepTotal == nil then break end
	local RepRevered, itemAmt, dailyAmt, foodAmt = RepTotal-21000
	if RepRevered < 0 then RepRevered = nil end

	local dailyReps = {L["Darkmoon Faire"],L["Baradin's Wardens"],L["Hellscream's Reach"],L["Wildhammer Clan"],L["Dragonmaw Clan"],L["Therazane"],L["Netherwing"],
		L["The Sons of Hodir"],L["Ogri'la"],L["The Kalu'ak"],L["The Anglers"],L["The Tillers"],L["The Klaxxi"],L["Golden Lotus"],L["The August Celestials"],
		L["Shado-Pan"],L["Operation: Shieldwall"],L["Dominance Offensive"],L["Sunreaver Onslaught"],L["Kirin Tor Offensive"]}
	local dailyAmts = {250,250,250,250,250,250,250,350,350,500,500,150,130,100,250,250,150,150,150,150}
	for i = 1, #dailyReps do -- Reps with dailies
	  if dailyReps[i] == RepName then
	    local dailyAmt, AmtRev, found = ceil(RepTotal / (dailyAmts[i]*RC_Bonus))
	    if RepRevered then AmtRev = ceil(RepRevered / dailyAmts[i]) end
	    if hasBonus then
		dailyAmt = ceil(dailyAmt/2) 
		if AmtRev then AmtRev = ceil(AmtRev/2) end
		if AmtRev then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: Approx " .. dailyAmt ..  " dailies required to reach exalted with " .. RepName .. ". ("..AmtRev.." to Revered)", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: Approx " .. dailyAmt ..  " dailies required to reach exalted with " .. RepName .. ".", 0, 0.7, 1) end
	    else
		if AmtRev then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: Approx " .. dailyAmt ..  " dailies required to reach exalted with " .. RepName .. ". ("..AmtRev.." to Revered)", 0, 0.7, 1)
		else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: Approx " .. dailyAmt ..  " dailies required to reach exalted with " .. RepName .. ".", 0, 0.7, 1) end
	    end
	  end
	end

	local farmReps = {L["Chee Chee"],L["Ella"],L["Farmer Fung"],L["Fish Fellreed"],L["Gina Mudclaw"],L["Haohan Mudclaw"],L["Jogu the Drunk"],L["Old Hillpaw"],L["Sho"],L["Tina Mudclaw"]}
	for i = 1, #farmReps do -- Farmers
	  if farmReps[i] == RepName then
	    foodAmt = ceil(RepTotal / (1800*RC_Bonus))
	    itemAmt = ceil(RepTotal / (900*RC_Bonus))
	    if RepName == L["Old Hillpaw"] then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. foodAmt ..  " \124cffffffff\124Hitem:74649:0:0:0:0:0:0:0:0\124h[Braised Turtle]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79265:0:0:0:0:0:0:0:0\124h[Blue Feather]\124h\124r hand-ins to become Best Friend with " .. RepName .. ".", 0, 0.7, 1) end
	    if RepName == L["Chee Chee"] then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. foodAmt ..  " \124cffffffff\124Hitem:74647:0:0:0:0:0:0:0:0\124h[Valley Stir Fry]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79265:0:0:0:0:0:0:0:0\124h[Blue Feather]\124h\124r hand-ins to become Best Friend with " .. RepName .. ".", 0, 0.7, 1) end
	    if RepName == L["Ella"] then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. foodAmt ..  " \124cffffffff\124Hitem:74651:0:0:0:0:0:0:0:0\124h[Shrimp Dumplings]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79266:0:0:0:0:0:0:0:0\124h[Jade Cat]\124h\124r hand-ins to become Best Friend with " .. RepName .. ".", 0, 0.7, 1) end
	    if RepName == L["Fish Fellreed"] then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. foodAmt ..  " \124cffffffff\124Hitem:74655:0:0:0:0:0:0:0:0\124h[Twin Fish Platter]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79266:0:0:0:0:0:0:0:0\124h[Jade Cat]\124h\124r hand-ins to become Best Friend with " .. RepName .. ".", 0, 0.7, 1) end
	    if RepName == L["Jogu the Drunk"] then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. foodAmt ..  " \124cffffffff\124Hitem:74643:0:0:0:0:0:0:0:0\124h[Sauteed Carrots]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79267:0:0:0:0:0:0:0:0\124h[Lovely Apple]\124h\124r hand-ins to become Best Friend with " .. RepName .. ".", 0, 0.7, 1) end
	    if RepName == L["Sho"] then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. foodAmt ..  " \124cffffffff\124Hitem:74645:0:0:0:0:0:0:0:0\124h[Eternal Blossom Fish]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79267:0:0:0:0:0:0:0:0\124h[Lovely Apple]\124h\124r hand-ins to become Best Friend with " .. RepName .. ".", 0, 0.7, 1) end
	    if RepName == L["Farmer Fung"] then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. foodAmt ..  " \124cffffffff\124Hitem:74654:0:0:0:0:0:0:0:0\124h[Wildfowl Roast]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79268:0:0:0:0:0:0:0:0\124h[Marsh Lily]\124h\124r hand-ins to become Best Friend with " .. RepName .. ".", 0, 0.7, 1) end
    	    if RepName == L["Gina Mudclaw"] then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. foodAmt ..  " \124cffffffff\124Hitem:74644:0:0:0:0:0:0:0:0\124h[Swirling Mist Soup]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79268:0:0:0:0:0:0:0:0\124h[Marsh Lily]\124h\124r hand-ins to become Best Friend with " .. RepName .. ".", 0, 0.7, 1) end
	    if RepName == L["Haohan Mudclaw"] then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. foodAmt ..  " \124cffffffff\124Hitem:74642:0:0:0:0:0:0:0:0\124h[Charbroiled Tiger Steak]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79264:0:0:0:0:0:0:0:0\124h[Ruby Shard]\124h\124r hand-ins to become Best Friend with " .. RepName .. ".", 0, 0.7, 1) end
    	    if RepName == L["Tina Mudclaw"] then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. foodAmt ..  " \124cffffffff\124Hitem:74652:0:0:0:0:0:0:0:0\124h[Fire Spirit Salmon]\124h\124r hand-ins, or "..itemAmt.." \124cff0070dd\124Hitem:79264:0:0:0:0:0:0:0:0\124h[Ruby Shard]\124h\124r hand-ins to become Best Friend with " .. RepName .. ".", 0, 0.7, 1) end
	  end
	end

	if RepName == L["Cenarion Circle"] then -- Other factions
	  itemAmt = ceil(RepTotal / (500*RC_Bonus)) * 10
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " \124cffffffff\124Hitem:20404:0:0:0:0:0:0:0:0\124h[Encrypted Twilight Text]\124h\124r to reach exalted with "..RepName..".", 0, 0.7, 1)
	elseif RepName == L["Nat Pagle"] then 
		itemAmt = ceil(RepTotal / (500*RC_Bonus))
		DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " \124cff1eff00\124Hitem:86542:0:0:0:0:0:0:0:0\124h[Flying Tiger Gourami]\124h\124r, \124cff1eff00\124Hitem:86545:0:0:0:0:0:0:0:0\124h[Mimic Octopus]\124h\124r, or \124cff1eff00\124Hitem:86544:0:0:0:0:0:0:0:0\124h[Spinefish Alpha]\124h\124r to reach exalted with Nat Pagle.", 0, 0.7, 1)
	elseif RepName == L["Kurenai"] or RepName == "Mag'har" then
	  itemAmt = ceil(RepTotal / (500*RC_Bonus)) * 10
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " \124cffffffff\124Hitem:25433:0:0:0:0:0:0:0:0\124h[Obsidian Warbeads]\124h\124r to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["The Consortium"] then
	  itemAmt = ceil(RepTotal / (250*RC_Bonus)) * 10
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " \124cffffffff\124Hitem:25433:0:0:0:0:0:0:0:0\124h[Obsidian Warbeads]\124h\124r or \124cffffffff\124Hitem:29209:0:0:0:0:0:0:0:0\124h[Zaxxis Insignia]\124h\124r to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["Sporeggar"] then
	  itemAmt = ceil(RepTotal / (750*RC_Bonus))* 5
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " \124cffffffff\124Hitem:24246:0:0:0:0:0:0:0:0\124h[Sanguine Hibiscus]\124h\124r to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["Wintersaber Trainers"] then
	  RepTotal = RepTotal - 10000; itemAmt = ceil(RepTotal / 1500)
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You have " .. itemAmt ..  " days of daily quests until exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["Ravenholdt"] then
	  itemAmt = ceil(RepTotal / (75*RC_Bonus)) * 5
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " \124cffffffff\124Hitem:16885:0:0:0:0:0:0:0:0\124h[Heavy Junkbox]\124h\124r to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["Sha'tari Skyguard"] then
	  itemAmt = ceil(RepTotal / (150*RC_Bonus)) * 6
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " \124cffffffff\124Hitem:32388:0:0:0:0:0:0:0:0\124h[Shadow Dust]\124h\124r to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == GetGuildInfo("player") then -- Guild Reputation
	  itemAmt = ceil(RepTotal / (166.6*RC_Bonus))
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: Approx " .. itemAmt ..  " quest hand-ins (" .. ceil(itemAmt/2) .. " with \124cffa335ee\124Hitem:69210:0:0:0:0:0:0:0:0\124h[Renowned Guild Tabard]\124h\124r) required to reach exalted with your guild.", 0, 0.7, 1)
	elseif RepName == L["Timbermaw Hold"] then
	  local itemAmt = ceil(RepTotal / (2000*RC_Bonus))* 5
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " \124cffffffff\124Hitem:21383:0:0:0:0:0:0:0:0\124h[Winterfall Spirit Beads]\124h\124r to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["The Scale of the Sands"] then
	  local itemAmt = ceil(RepTotal / (7800*RC_Bonus))
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: Approx " .. itemAmt ..  " full Hyjal Summit clears to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["The Scryers"] then
	  local itemAmt = ceil(RepTotal / (350*RC_Bonus))
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " \124cff1eff00\124Hitem:29739:0:0:0:0:0:0:0:0\124h[Arcane Tome]\124h\124r to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["The Aldor"] then
	  local itemAmt = ceil(RepTotal / (350*RC_Bonus))
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " \124cff1eff00\124Hitem:29740:0:0:0:0:0:0:0:0\124h[Fel Armament]\124h\124r to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["Silverwing Sentinels"] or RepName == L["Warsong Outriders"] then
	  local itemAmt = ceil(RepTotal / (35*RC_Bonus))
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " Warsong Gulch flag captures to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["The League of Arathor"] or RepName == "The Defilers" then
	  local itemAmt = ceil(RepTotal / (100*RC_Bonus))
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " Arathi Basin wins to reach exalted with " .. RepName ..  ".", 0, 0.7, 1)
	elseif RepName == L["Order of the Cloud Serpent"] then
	  if hasBonus then RC_Bonus = RC_Bonus*2 end 
	  local dailyAmt = ceil(RepTotal / (2000*RC_Bonus))
	  local dailyAmt2 = ceil(RepTotal / (1500*RC_Bonus))
	  local itemAmt = ceil(RepTotal / (500*RC_Bonus))
	  DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require "..dailyAmt.." days of dailies incl. profession-based, or "..dailyAmt2.." days without, to reach exalted with "..RepName..". Alternatively, you require "..itemAmt.." \124cffffffff\124Hitem:89155:0:0:0:0:0:0:0:0\124h[Onyx Egg]\124h\124r to reach exalted.", 0, 0.7, 1)
	elseif RepName == L["The Black Prince"] then
	  local itemAmt = ceil(RepTotal / (20*RC_Bonus))
	  local itemAmt2
	  if RepTotal > 21000 then itemAmt2 = ceil((RepTotal-21000) / (20*RC_Bonus)) end
	  if itemAmt2 then DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require " .. itemAmt ..  " mob kills to reach exalted with " .. RepName ..  ". ("..itemAmt2.." to Revered).", 0, 0.7, 1)
	  else DEFAULT_CHAT_FRAME:AddMessage("RepCalc: You require approximately " .. itemAmt ..  " mob kills to reach exalted with " .. RepName ..  ".", 0, 0.7, 1) end
	end
        break
      end
    end
  end
end